Enum ProcessStatus
Source pub enum ProcessStatus {
Ready,
Running,
Waiting,
Zombie(i32),
}
Ready to be run by the scheduler
Currently running on a CPU
Waiting on a resource (I/O, a lock, …)
Exited; also contains an exit code
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.